asr.phonopy
===========

.. automodule:: asr.phonopy

   
   
   .. rubric:: Functions

   
   .. autofunction:: lattice_vectors
   .. autofunction:: plot_bandstructure
   .. autofunction:: plot_phonons
   .. autofunction:: requires
   .. autofunction:: webpanel
   
   

   
   
   

   
   
   